/*		 ICP-PCI Kernel module free public release
 *
 *		       Copyright (C) 1996-99 GOM mbH.
 *	         Rebenring 33, 38106 Braunschweig, GERMANY
 *		            All rights reserved
 *
 * $Id: icpciReg.h,v 5.1.2.2 1999/07/13 07:43:16 matthias Exp $
 *
 */

#ifndef _ICPCIREG_H
#define _ICPCIREG_H

#if defined(linux) && defined(__KERNEL__)

/* IC-PCI Hardware Reference Manual; Imaging Technology Inc. */
/* Document Number 47-H600002-0[0|1]; March 1995, revised March 1998 */

/* R-O   Read-Only Register */
/* W-O   Write-Only Register */
/* R/W   Read/Write Register */
/* R/W1C Clear on Write One to Register */
/* R/W0C Clear on Write Zero to Register */

/* PCI Interface Control Registers (32bit access only), pages 3-17 to 3-24 */
/* *********************************************************************** */

/* 
 * Prototypes
 */

/* special interrupt handler */ 

void xcr_test_irqs (u_char, u_long*);
void xcr_clear_irqs (u_char);

/* read handler */

u_long icr_get_mbox1 (u_char);
u_long icr_get_mbox2 (u_char);
u_long icr_get_mbox3 (u_char);
u_long icr_get_mbox4 (u_char);
u_long icr_get_bmdst (u_char);
u_long icr_get_bmxc (u_char);
u_char icr_get_inten (u_char);
u_char icr_get_binten (u_char);
u_char icr_get_intst (u_char);
u_char icr_get_bintst (u_char);
u_char icr_get_maint (u_char);
u_char icr_get_taint (u_char);
u_char icr_get_flip (u_char); /* REV-B Only! */
u_char icr_get_fifofl (u_char);
u_char icr_get_fifo4p (u_char);
u_char icr_get_fifoem (u_char);
u_char icr_get_bmdone (u_char);
u_char icr_get_bmreq (u_char);

/* write handler */

int icr_set_mbox1 (u_char, u_long);
int icr_set_mbox2 (u_char, u_long);
int icr_set_mbox3 (u_char, u_long);
int icr_set_mbox4 (u_char, u_long);
int icr_set_bmdst (u_char, u_long);
int icr_set_bmxc (u_char, u_long); 
int icr_set_inten (u_char, u_char);
int icr_set_binten (u_char, u_char);
int icr_set_flip (u_char, u_char); /* REV-B Only! */
int icr_set_bmreq (u_char, u_char); 

/* clear handler */

int icr_clear_fifoclr (u_char);

/* init handler */

int icr_init_intctl (u_char);
int icr_init_bmctl (u_char);

/* end of prototypes */

#define ICR_DISABLE		0
#define ICR_ENABLE		1

#define	ICR_REG_SIZE		16

#define ICP_REV_A		0x03	/* first board layout till # */
#define ICP_REV_B		0x04	/* second board layout from # */
					/* 24bit acquisition AND storage */
					/* write zoom (hardware decimation) */
					/* clipping 0x00-0x0F/0xF0-0cFF */
					/* 8bit parallel i/o ports with
					   strobe and interrupts */

#define ICR_NO_MASK		0xFFFFFFFF	/* no range checking */
#define ICR_NO_MIN		0x00000000
#define ICR_NO_MAX		0xFFFFFFFF
#define ICR_NO_SHIFT		0

#define ICR_MBOX_MASK		ICR_NO_MASK
#define ICR_MBOX_MIN		ICR_NO_MIN
#define ICR_MBOX_MAX		ICR_NO_MAX
#define ICR_MBOX_INIT		0x00000000

/*    u_long	mbox1;		Mailbox Register 0 R/W */

#define ICR_MBOX1_OFFSET	0x00

/*    u_long	mbox2;		Mailbox Register 1 R/W */

#define ICR_MBOX2_OFFSET	0x04

/*    u_long	mbox3;		Mailbox Register 2 R/W */

#define ICR_MBOX3_OFFSET	0x08

/*    u_long	mbox4;		Mailbox Register 3 R/W */

#define ICR_MBOX4_OFFSET	0x0C

/*    u_long	reserved_1[5];	not used 0x10, 0x14, 0x18, 0x1C, 0x20 */

/*    u_long	bmdst;		Bus Master Destination Address */
/*				0:31/ 32bit boundary - R/W */

#define ICR_BMDST_OFFSET	0x24
#define ICR_BMDST_MASK		0xFFFFFFFC
#define ICR_BMDST_MIN		ICR_NO_MIN
#define ICR_BMDST_MAX		ICR_NO_MAX
#define ICR_BMDST_INIT		0x00000000

/*    u_long	bmxc;		Bus Master Transfer Count */
/*                              0:20(2Mb)/ 0:21(4Mb) - R/W */

#define ICR_BMXC_OFFSET		0x28
#define ICR_BMXC_MASK 		0x001FFFFF
#define ICR_BMXC_MIN		ICR_NO_MIN
#define ICR_BMXC_MAX		ICR_BMXC_MASK
#define ICR_BMXC_INIT		0x00000000

/*    u_long	reserved_2[3];	not used 0x2C, 0x30, 0x34 */

/*    u_long	intctl;		Interrupt Control Status */
/*-------------------------------------------------------*/

#define ICR_INTCTL_OFFSET	0x38
#define ICR_INTCTL_INIT		0x00360F00

				/* PCI Interrupt Disable */
				/* Bus Master Transfer Done Interrupt
				   Disable */
				/* Clear PCI Interrupt Status R/W1C */
				/* Clear Bus Master Transfer Done Interrupt
				   R/W1C */
				/* Clear Master Abort Interrupt Status
				   R/W1C */
				/* Clear Target Abort Interrupt Status
				   R/W1C */

#define ICR_IRQ_TEST_MASK	0x00360000;	/* here are intr. status bits
						   see test_and_clear_irq */

/*    u_long	zero_1:8;	reset to 0 */
/*    u_long	one_1:4;	set to 1 */

/*    u_long    inten:1;	PCI Interrupt Enable R/W */

#define ICR_INTEN_MASK		0x00001000
#define ICR_INTEN_SHIFT		12

/*    u_long	zero_2:1;	reset to 0  */
/*    u_long	binten:1;	Interrupt on Bus Mater Transfer */
				/* Done Enable R/W */

#define ICR_BINTEN_MASK		0x00004000
#define ICR_BINTEN_SHIFT	14

/*    u_long	res_1:2;	reserved - reset to 0 */
/*    u_long	intst:1;	PCI Interrupt Status R/W1C */

#define ICR_INTST_MASK		0x00020000
#define ICR_INTST_SHIFT		17

/*    u_long	bintst:1;	Bus Master Interrupt Status R/W1C */

#define ICR_BINTST_MASK		0x00040000
#define ICR_BINTST_SHIFT	18

/*    u_long	res_2:1;	reserved - reset to 0 */
/*    u_long	maint:1;	Master Abort Interrupt Status R/W1C */

#define ICR_MAINT_MASK		0x00100000
#define ICR_MAINT_SHIFT		20

/*    u_long	taint:1;	Target Abort Interrupt Status R/W1C */

#define ICR_TAINT_MASK		0x00200000
#define ICR_TAINT_SHIFT		21

/*    u_long	zero_3:1;	reset to 0  */
/*    u_long	res_3:1;	reserved - reset to 0 */
/*    u_long	zero_4:1;	reset to 0  */

/*    u_long	flip:1;		Data Byte Swap (AMCC S5933QE only!?) */
/*                              we assume REV-B boards support this */

#define ICR_FLIP_MASK		0x02000000
#define ICR_FLIP_SHIFT		25

/*    u_long	zero_5:6;	reset to 0  */

/*    u_long	bmctl;		Bus Master Host Control/Status */
/*-------------------------------------------------------------*/

#define ICR_BMCTL_OFFSET	0x3C
#define ICR_BMCTL_INIT		0x04000300
				/* Bus Request Disable */
				/* Disable Software Reset */
				/* FIFO Clear*/

/*    u_long	res_1:3;	reserved - reset to 0 */
/*    u_long	fifofl:1;	FIFO Full (8 x 32bit) R-O */

#define ICR_FIFOFL_MASK		0x00000008
#define ICR_FIFOFL_SHIFT	3

/*    u_long	fifo4p:1;	FIFO Half Full (4 x 32bit) R-O */

#define ICR_FIFO4P_MASK		0x00000010
#define ICR_FIFO4P_SHIFT	4

/*     u_long	fifoem:1;	FIFO Empty (0 x 32bit) R-O */

#define ICR_FIFOEM_MASK		0x00000020
#define ICR_FIFOEM_SHIFT	5

/*    u_long	res_2:1;	reserved - reset to 0 */
/*    u_long	bmdone:1;	Bus Master Transfer Done R-O */

#define ICR_BMDONE_MASK		0x00000080
#define ICR_BMDONE_SHIFT	7

/*    u_long	bmreq:3;	Bus Request R/W */

#define ICR_BMREQ_MASK		0x00000400
#define ICR_BMREQ_SHIFT		10

/* since the revised manual (March 1998) these are also the offical values */
#define ICR_BMREQ_STOP_MASK	0x00000700
#define ICR_STOP_TRANS		0x00000300
#define ICR_BMREQ_STRT_MASK	0xF0FFFF00
#define ICR_STRT_TRANS		0x00000400

/*    u_long	zero_1:13;	reset to 0 */
/*    u_long	rst:1;		Software Reset R/W */

#define ICR_RST_MASK		0x01000000
#define ICR_RST_SHIFT		24

/*    u_long	res_3:1;	reserved - reset to 0 */
/*    u_long	fifclr:1;	FIFO Clear W-O */

#define ICR_FIFOCLR_MASK	0x04000000
#define ICR_FIFOCLR_SHIFT	26

/*    u_long	res_4:1;	reserved - reset to 0 */
/*    u_long	zero_2:4;	reset to 0 */



/* IC-PCI Control Registers (16bit access only), pages 3-25 to 3-40 */
/* access via memory mapped registers **OR** special i/o operations */
/* **************************************************************** */

/*
 * Prototypes
 */

/* read handler */

u_char cr_get_bmstren (u_char);
u_char cr_get_bmilace (u_char);
u_char cr_get_pixsz (u_char);
u_char cr_get_memcfg (u_char); 
u_char cr_get_vbstat (u_char); 
u_char cr_get_fldstat (u_char);
u_char cr_get_smstat (u_char); 
u_char cr_get_amp (u_char);
u_char cr_get_tmode (u_char);
u_char cr_get_fcnt (u_char);
u_char cr_get_fldsel (u_char); 
u_char cr_get_acqmd (u_char);
u_char cr_get_newaq (u_char);
u_char cr_get_gstat (u_char);
u_char cr_get_fstrt (u_char);
u_short cr_get_pitch (u_char); 
u_short cr_get_aoix (u_char);
u_long cr_get_bmsf (u_char);
u_long cr_get_bmss (u_char);
u_long cr_get_aqstart (u_char);
u_long cr_get_aqadr (u_char); 
u_long cr_get_intadr (u_char);
u_char cr_get_vbien (u_char);
u_char cr_get_ovbien (u_char); 
u_char cr_get_evbien (u_char); 
u_char cr_get_amien (u_char);
u_char cr_get_trigien (u_char);
u_char cr_get_adrien (u_char); 
u_char cr_get_aqien (u_char);
u_char cr_get_vbint (u_char);
u_char cr_get_ovbint (u_char); 
u_char cr_get_evbint (u_char); 
u_char cr_get_amint (u_char);
u_char cr_get_trigint (u_char);
u_char cr_get_adrint (u_char); 
u_char cr_get_aqint (u_char);
u_char cr_get_hdec (u_char);	/* REV-B Only! */
u_char cr_get_vdec (u_char);	/* REV-B Only! */
u_char cr_get_clip (u_char);	/* REV-B Only! */
u_char cr_get_bmzoom (u_char);	/* PCVision Only! */
u_char cr_get_outstrb (u_char);	/* REV-B Only! */
u_char cr_get_inregenb (u_char);	/* REV-B Only! */
u_char cr_get_instrbpol (u_char);	/* REV-B Only! */
u_char cr_get_inregclr (u_char);	/* REV-B Only! */
u_char cr_get_inportien (u_char);	/* REV-B Only! */
u_char cr_get_inportpol (u_char);	/* REV-B Only! */
u_char cr_get_inportint (u_char);	/* REV-B Only! */
u_char cr_get_inportrint (u_char);	/* REV-B Only! */
u_char cr_get_inportrstrb (u_char);	/* REV-B Only! */
u_char cr_get_pad16 (u_char);	/* PCVision Only! */
u_char cr_get_outport (u_char);	/* REV-B Only! */
u_char cr_get_inport (u_char);	/* REV-B Only! */

/* write handler */

int cr_set_bmstren (u_char, u_char);
int cr_set_bmilace (u_char, u_char);
int cr_set_pixsz (u_char, u_char);
int cr_set_memcfg (u_char, u_char); 
int cr_set_tmode (u_char, u_char);
int cr_set_fcnt (u_char, u_char);
int cr_set_fldsel (u_char, u_char);
int cr_set_acqmd (u_char, u_char);
int cr_set_pitch (u_char, u_short);
int cr_set_aoix (u_char, u_short);
int cr_set_bmsf (u_char, u_long);
int cr_set_bmss (u_char, u_long);
int cr_set_aqstart (u_char, u_long);
int cr_set_intadr (u_char, u_long);
int cr_set_vbien (u_char, u_char);
int cr_set_ovbien (u_char, u_char);
int cr_set_evbien (u_char, u_char);
int cr_set_amien (u_char, u_char);
int cr_set_trigien (u_char, u_char);
int cr_set_adrien (u_char, u_char);
int cr_set_aqien (u_char, u_char);
int cr_set_hdec (u_char, u_char);	/* REV-B Only! */
int cr_set_vdec (u_char, u_char);	/* REV-B Only! */
int cr_set_clip (u_char, u_char);	/* REV-B Only! */
int cr_set_bmzoom (u_char, u_char);	/* PCVision Only! */
int cr_set_outstrb (u_char, u_char);	/* REV-B Only! */
int cr_set_inregenb (u_char, u_char);	/* REV-B Only! */
int cr_set_instrbpol (u_char, u_char);	/* REV-B Only! */
int cr_set_inregclr (u_char, u_char);	/* REV-B Only! */
int cr_set_inportien (u_char, u_char);	/* REV-B Only! */
int cr_set_inportpol (u_char, u_char);	/* REV-B Only! */
int cr_set_pad16 (u_char, u_char);	/* PCVision Only! */
int cr_set_outport (u_char, u_char);	/* REV-B Only! */

/* init handler */

int cr_init_con (u_char);
int cr_init_acqcon (u_char);
int cr_init_intcon (u_char);
int cr_init_wzoom (u_char);
int cr_init_mdata (u_char);
int cr_init_portcon (u_char);
int cr_init_outport (u_char);
int cr_init_inport (u_char);

/* end of prototypes */

#define CR_DISABLE		0
#define CR_ENABLE		1

#define	CR_REG_SIZE		19

#define CR_NO_MASK		0xFFFF		/* no range checking */
#define CR_NO_MIN		0x0000
#define CR_NO_MAX		0xFFFF

/*    u_short      con;		Control */
/*--------------------------------------*/

#define CR_CON_OFFSET		0x00
#define CR_CON_INIT		0x0000
				/* Bus Master Disable */
				/* De-Interlacing Disabled */
				/* Camera Pixel Size 1 to 8 bits*/
				/* 2Mb Frame Grabber Memory */

/*    u_short	bmstren:1;	Bus Master Memory Access R/W */

#define CR_BMSTREN_MASK 	0x0001
#define CR_BMSTREN_SHIFT 	0

/*    u_short	bmilace:1;	Bus Master Interlaced Images R/W */

#define CR_BMILACE_MASK		0x0002
#define CR_BMILACE_SHIFT	1

/*    u_short	pixsz:2;	Camera Pixel Size R/W */

#define CR_PIXSZ_MASK		0x000C
#define CR_PIXSZ_SHIFT		2
#define CR_PIXSZ_8		0	/* Camera Pixel Size  1 to  8 bit */
#define CR_PIXSZ_16		1	/* Camera Pixel Size  9 to 16 bit */
#define CR_PIXSZ_24_32		2	/* Camera Pixel Size 17 to 24 bit */
					/* one pixel is stored in 32 bit */
#define CR_PIXSZ_24_24		3	/* Camera Pixel Size 17 to 24 bit */
					/* one pixel is stored in 24 bit */
					/* REV-B Only! */

/*    u_short	memcfg:1;	Memory Configuration R/W */

#define CR_MEMCFG_MASK		0x0010
#define CR_MEMCFG_SHIFT		4
#define CR_MEM_2		0	/* 2 MByte Frame Buffer Memory */
#define CR_MEM_4		1	/* 4 MByte Frame Buffer Memory */

/*    u_short	vbstat:1;	Camera Vertical Blank Status R-O */

#define CR_VBSTAT_MASK		0x0020
#define CR_VBSTAT_SHIFT		5
#define CR_IN_VB		0	/* Camera in Vertical Blank */
#define CR_OUT_VB		1	/* Camera not in Vertical Blank */

/*    u_short	fldstat:1;	Camera Field Status R-O */

#define CR_FLDSTAT_MASK 	0x0040
#define CR_FLDSTAT_SHIFT	6
#define CR_IN_EVEN_FIELD	0	/* Camera in Even Field */
#define CR_IN_ODD_FIELD		1	/* Camera in Odd Field */

/*    u_short	smstat:1;	Camera Scan Mode Status R-O */

#define CR_SMSTAT_MASK  	0x0080
#define CR_SMSTAT_SHIFT		7
#define CR_NON_ILACE		0	/* Non-Interlaced Video */
#define CR_ILACE		1	/* Interlaced Video */

/*    u_short	amp:1;		Acquisition Module Present R-O */

#define CR_AMP_MASK		0x0100
#define CR_AMP_SHIFT		8
#define CR_AM_PESENT		0	/* Acquisition Module installed */
#define CR_AM_ABSENT		1	/* No Acquisition Module present */

/*    u_short	res_1:7;	reserved - reset to 0 */

/*    u_short	acqcon;		Acquire Control */
/*----------------------------------------------*/

#define CR_ACQCON_OFFSET	0x02

#define CR_ACQCON_INIT		0x0080
				/* Trigger Disabled */
				/* Acquire 1 frame */
				/* Start Acquire at Even Field */
				/* Freeze */

/*    u_short	tmode:1;	Trigger Mode Acquisition R/W */

#define CR_TMODE_MASK		0x0001
#define CR_TMODE_SHIFT		0

/*    u_short	fcnt:3;		Snap Frame Count R/W */

#define CR_FCNT_MASK		0x000E
#define CR_FCNT_SHIFT		1
#define CR_FCNT_MIN		CR_NO_MIN
#define CR_FCNT_MAX		CR_FCNT_MASK >> CR_FCNT_SHIFT

/*    u_short	res_1:2;	reserved - reset to 0 */

/*    u_short	fldsel:2;	Starting Field Select R/W */

#define CR_FLDSEL_MASK		0x00C0
#define CR_FLDSEL_SHIFT		6
#define CR_NEXT_FIELD		0	/* Start Acquisition at Next Field */
#define CR_EVEN_FIELD		2	/* Start Acquisition at Even Field */
#define CR_ODD_FIELD		3	/* Start Acquisition at Odd Field */

/*    u_short	acqmd:2;	Acquisition Mode R/W */

#define CR_ACQMD_MASK		0x0300
#define CR_ACQMD_SHIFT		8
#define CR_FREEZE		0	/* Freeze */
#define CR_SNAP			2	/* Snap */
#define CR_GRAB			3	/* Grab */

/*    u_short	newaq:1;	New Acquire R-O */ 

#define CR_NEWAQ_MASK		0x0400
#define CR_NEWAQ_SHIFT		10

/*    u_short	gstat:1;	GRAB Status R-O */

#define CR_GSTAT_MASK		0x0800
#define CR_GSTAT_SHIFT		11

/*    u_short	fstrt:1;	Field Start Status R-O */
/*    u_short	res_2:3;	reserved - reset to 0 */

#define CR_FSTRT_MASK		0x1000
#define CR_FSTRT_SHIFT		12
#define CR_FIELD_EVEN		0	/* I-laced Video start on even field */
#define CR_FIELD_ODD		1	/* I-laced Video start on odd field */

/*    u_short	pitch;		Image Pitch = n * pixel per line / 8 */
/*                              n = 1-8bit/ 2-16bit/ 4-24bit) */
/*                              0:11 -> 3:14 R/W */

#define CR_PITCH_OFFSET		0x04
#define CR_PITCH_MASK		0x0FFF
#define CR_PITCH_SHIFT		3
#define CR_PITCH_MIN		1
#define CR_PITCH_MAX		CR_PITCH_MASK
#define CR_PITCH_INIT		8 /* 8 pixels per line (8bit) */

/*    u_short	aoix;		Area Of Interest Horizontal Dimension */
/*				= n * pixel per line / 8 */
/*                              n = 1-8bit/ 2-16bit/ 4-24bit) */
/*                              0:11 -> 3:14 R/W */

#define CR_AOIX_OFFSET		0x06
#define CR_AOIX_MASK		CR_PITCH_MASK
#define CR_AOIX_SHIFT		CR_PITCH_SHIFT
#define CR_AOIX_MIN		CR_PITCH_MIN
#define CR_AOIX_MAX		CR_PITCH_MAX
#define CR_AOIX_INIT		CR_PITCH_INIT

/*    u_short	bmsfl;		Bus Master First Field Start Address */
/*				Low 0:9 -> 3:12 R/W */

#define CR_BMSFL_OFFSET		0x08
#define CR_BMSFL_MASK		0x03FF
#define CR_BMSFL_SHIFT		3
#define CR_BMSFL_MIN		CR_NO_MIN
#define CR_BMSFL_MAX		CR_BMSFL_MASK

/*    u_short	bmsfh;		Bus Master First Field Start Address */
/*				High 0:8 -> 13:21(4Mb) 13:20(2Mb) R/W */

#define CR_BMSFH_OFFSET		0x0A
#define CR_BMSFH_MASK 		0x00FF
#define CR_BMSFH_SHIFT		13
#define CR_BMSFH_MIN		CR_NO_MIN
#define CR_BMSFH_MAX		CR_BMSFH_MASK
#define CR_BMSF_INIT		0x0000

/*    u_short	bmssl;		Bus Master Second Field Start Address */
/*				Low 0:9 -> 3:12 R/W */

#define CR_BMSSL_OFFSET		0x0C
#define CR_BMSSL_MASK		CR_BMSFL_MASK
#define CR_BMSSL_SHIFT		CR_BMSFL_SHIFT
#define CR_BMSSL_MIN		CR_BMSFL_MIN
#define CR_BMSSL_MAX		CR_BMSFL_MAX

/*    u_short	bmssh;		Bus Master Second Field Start Address */
/*				High 0:8 -> 13:21(4Mb) 13:20(2Mb) R/W */

#define CR_BMSSH_OFFSET		0x0E
#define CR_BMSSH_MASK		CR_BMSFH_MASK
#define CR_BMSSH_SHIFT		CR_BMSFH_SHIFT
#define CR_BMSSH_MIN		CR_BMSFH_MIN
#define CR_BMSSH_MAX		CR_BMSFH_MAX
#define CR_BMSS_INIT		CR_BMSF_INIT

/*    u_short	aqstart		Acquisition Start Address */
/*                              0:9 -> 12-21(4Mb) 12-20(2Mb) R/W */

#define CR_AQSTART_OFFSET	0x10
#define CR_AQSTART_MASK		0x01FF
#define CR_AQSTART_SHIFT	12
#define CR_AQSTART_MIN		CR_NO_MIN
#define CR_AQSTART_MAX		CR_AQSTART_MASK
#define CR_AQSTART_INIT		0x0000

/*    u_short	aqadr;		Acquisition Address Status */
/*                              0:9 -> 12-21(4Mb) 12-20(2Mb) R-O */

#define CR_AQADR_OFFSET		0x12
#define CR_AQADR_MASK		CR_AQSTART_MASK
#define CR_AQADR_SHIFT		12
#define CR_AQADR_MIN		CR_NO_MIN
#define CR_AQADR_MAX		CR_AQADR_MASK

/*    u_short	intadr;		Acquisition Address Interrupt */
/*                              0:5 -> 16-21(4Mb) 16-20(2Mb) R/W */

#define CR_INTADR_OFFSET	0x14
#define CR_INTADR_MASK		0x003F
#define CR_INTADR_SHIFT		16
#define CR_INTADR_MIN		CR_NO_MIN
#define CR_INTADR_MAX		CR_INTADR_MASK
#define CR_INTADR_INIT		0x0000

/*    u_short	intcon;		Interrupt Control */
/* -----------------------------------------------*/

#define CR_INTCON_OFFSET	0x16
#define CR_INTCON_INIT		0x0000
				/* No Interrupt Enabled */
				/* Clear All Interrupts R/W0C */

#define CR_IRQ_TEST_MASK	0x3F80	/* here are intr. status bits
					   see xcr_test_and_clear_irq */

/*    u_short	vbien:1;	Vertikal Blank Interrupt R/W0C*/

#define CR_VBIEN_MASK		0x0001
#define CR_VBIEN_SHIFT		0

/*    u_short	ovbien:1;	Odd Vertikal Blank Interrupt R/W0C */

#define CR_OVBIEN_MASK		0x0002
#define CR_OVBIEN_SHIFT		1

/*    u_short	evbien:1;	Even Vertikal Blank Interrupt R/W0C */

#define CR_EVBIEN_MASK		0x0004
#define CR_EVBIEN_SHIFT		2

/*    u_short	amien:1;	AM Interrupt R/W0C */

#define CR_AMIEN_MASK		0x0008
#define CR_AMIEN_SHIFT		3

/*    u_short	trigien:1;	External Trigger Interrupt R/W0C */

#define CR_TRIGIEN_MASK		0x0010
#define CR_TRIGIEN_SHIFT	4

/*    u_short	adrien:1;	Acquire Address Interrupt R/W0C */

#define CR_ADRIEN_MASK		0x0020
#define CR_ADRIEN_SHIFT		5

/*    u_short	aqien:1;	Acquire Interrupt R/W0C */

#define CR_AQIEN_MASK		0x0040
#define CR_AQIEN_SHIFT		6

/*    u_short	vbint:1;	Vertikal Blank Interrupt Status R-O */

#define CR_VBINT_MASK		0x0080
#define CR_VBINT_SHIFT		7

/*    u_short	ovbint:1;	Odd Vertikal Blank Interrupt Status R-O */

#define CR_OVBINT_MASK		0x0100
#define CR_OVBINT_SHIFT		8

/*    u_short	evbint:1;	Even Vertikal Blank Interrupt Status R-O */

#define CR_EVBINT_MASK		0x0200
#define CR_EVBINT_SHIFT		9

/*    u_short	amint:1;	AM Interrupt Status R-O */

#define CR_AMINT_MASK		0x0400
#define CR_AMINT_SHIFT		10

/*    u_short	trigint:1;	External Trigger Interrupt Status R-O */

#define CR_TRIGINT_MASK		0x0800
#define CR_TRIGINT_SHIFT	11

/*    u_short	adrint:1;	Acquisition Address Interrupt Status R-O */

#define CR_ADRINT_MASK		0x1000
#define CR_ADRINT_SHIFT		12

/*    u_short	aqint:1;	Acquisition Interrupt Status R-O */

#define CR_AQINT_MASK		0x2000
#define CR_AQINT_SHIFT		13

/*    u_short	res_1:2;	reserved -reset to 0 */

/*    u_short	wzoom;		Write Zoom Control (REV-B Only!) */
/* ------------------------------------------------------------*/

#define CR_WZOOM_OFFSET		0x18
#define CR_WZOOM_INIT		0x0000
				/* No Horizontal or Vertical Decimation */
				/* No Clipping */
				/* No Bus Master Zoom Mode (PCVision Only!) */

/*    u_short	hdec:2;		Horizontal Decimation R/W (REV-B Only!) */

#define CR_HDEC_MASK		0x0003
#define CR_HDEC_SHIFT		0

#define CR_DEC_BY_1		0	/* no decimation (original image) */
#define CR_DEC_BY_2		1	/* a half of the width/height */
#define CR_DEC_BY_4		2	/* a quarter of the width/height */
#define CR_DEC_BY_8		3	/* 1/8 of the width/height */

/*    u_short	vdec:2;		Vertical Decimation R/W (REV-B Only!) */

#define CR_VDEC_MASK		0x000C
#define CR_VDEC_SHIFT		2

/* for values see hdec bits above */

/*    u_short	clip:1;		Bus Master Clipping Enable (REV-B Only!) */

#define CR_CLIP_MASK		0x0010
#define CR_CLIP_SHIFT		4

/*    u_short	res_1:2;	reserved -reset to 0 */

/*    u_short	bmzoom:1;	Bus Master Zoom Mode (PCVision Only!) */

#define CR_BMZOOM_MASK		0x0080
#define CR_BMZOOM_SHIFT		7

/*    u_short	res_2:8;	reserved -reset to 0 */

/*    u_short	mdata;		Mask Data */
/*                              0:15 set to 1 W-O */

#define CR_MDATA_OFFSET		0x1A
#define CR_MDATA_INIT		0xFFFF

/*    u_short	portcon;	Port Control (REV-B Only!) */
/* --------------------------------------------------------*/

#define CR_PORTCON_OFFSET	0x20
#define CR_PORTCON_INIT		0x002D
				/* Strobe Pin Driven High */
				/* Disable Input Buffer and Strobe */
				/* Falling Edge Clocks Data into Buffer */
				/* Input Buffer Cleared */
				/* Input Port Interrupt Disabled */
				/* Input Port Interrupt at Falling Edge */
				/* No Padding (PCVision Only!) */

/*    u_short	outsb:1;	Output Port Strobe R/W (REV-B Only!) */

#define CR_OUTSTRB_MASK		0x0001
#define CR_OUTSTRB_SHIFT	0

/*    u_short	inreg_enb:1;	Input Buffer Enable R/W (REV-B Only!) */

#define CR_INREG_ENB_MASK	0x0002
#define CR_INREG_ENB_SHIFT	1

/*    u_short	instb_pol:1;	Input Port Strobe Polarity R/W (REV-B Only!) */

#define CR_INSTRB_POL_MASK	0x0004
#define CR_INSTRB_POL_SHIFT	2
#define CR_INSTRB_ACT_HIGH	0	/* Rising Edge Clocks Date into Buf */
#define CR_INSTRB_ACT_LOW	1	/* Falling Edge Clocks Date into Buf */

/*    u_short	inreg_clr:1;	Input Buffer Clear R/W (REV-B Only!) */

#define CR_INREG_CLR_MASK	0x0008
#define CR_INREG_CLR_SHIFT	3

/*    u_short	inport_ien:1;	Input Port Intr. Enable R/W0C (REV-B Only!) */

#define CR_INPORT_IEN_MASK	0x0010
#define CR_INPORT_IEN_SHIFT	4

/*    u_short	inport_ipol:1;	Input Port Intr. Polarity R/W (REV-B Only!) */

#define CR_INPORT_POL_MASK	0x0020
#define CR_INPORT_POL_SHIFT	5
#define CR_INPORT_ACT_HIGH	0	/* Rising Edge causes an Interrupt */
#define CR_INPORT_ACT_LOW	1	/* Falling Edge causes an Interrupt */

/*    u_short	inport_int:1;	Input Port Intr. Status R-O (REV-B Only!) */

#define CR_INPORT_INT_MASK	0x0040
#define CR_INPORT_INT_SHIFT	6

/*    u_short	res_1:1;	reserved -reset to 0 */

/*    u_short	inport_rint:1;	Input Port Intr. Pin R-O (REV-B Only!) */

#define CR_INPORT_RINT_MASK	0x0100
#define CR_INPORT_RINT_SHIFT	8

/*    u_short	inport_rstb:1;	Input Port Strobe Pin R-O (REV-B Only!) */

#define CR_INPORT_RSTB_MASK	0x0200
#define CR_INPORT_RSTB_SHIFT	9

/*    u_short	res_2:2;	reserved -reset to 0 */

/*    u_short	pad16:1;	16bit Padding Enable R/W (PCVision Only!)*/

#define CR_PAD16_MASK		0x1000
#define CR_PAD16_SHIFT		12

/*    u_short	res_3:3;	reserved -reset to 0 */

/*    u_short	outport;	Output Port R/W (REV-B Only!) */
/*                              0:7 -> 8bit Out */

#define CR_OUTPORT_OFFSET	0x22
#define CR_OUTPORT_MASK		0x00FF
#define CR_OUTPORT_SHIFT	0
#define CR_OUTPORT_MIN		CR_NO_MIN
#define CR_OUTPORT_MAX		CR_OUTPORT_MASK
#define CR_OUTPORT_INIT		0x0000

/*    u_short	inport;		Input Port R/W (REV-B Only!) */
/*                              0:7 -> 8bit In */

#define CR_INPORT_OFFSET	0x24
#define CR_INPORT_MASK		0x00FF
#define CR_INPORT_SHIFT		0
#define CR_INPORT_MIN		CR_NO_MIN
#define CR_INPORT_MAX		CR_INPORT_MASK
#define CR_INPORT_INIT		0x0000

#endif /* linux && __KERNEL__ */

#endif /* _ICPCIREG_H */

